@@ -1,7 +1,7 @@
 import time
 
 from aminer import AMinerConfig
-from aminer.AMinerUtils import AnalysisContext
+from aminer.AnalysisChild import AnalysisContext
 from aminer.events import EventSourceInterface
 from aminer.input import AtomHandlerInterface
 from aminer.util import PersistencyUtil
@@ -84,8 +84,7 @@ class NewMatchPathValueComboDetector(AtomHandlerInterface,
 
     delta=self.nextPersistTime-time
     if(delta<0):
-      PersistencyUtil.storeJson(self.persistenceFileName, list(self.knownValuesSet))
-      self.nextPersistTime=None
+      self.doPersist()
       delta=600
     return(delta)
 
