@@ -10,11 +10,16 @@ class SequenceModelElement:
   def getChildElements(self):
     return(children)
 
-  """@return None when there is no match, MatchElement otherwise."""
   def getMatchElement(self, path, matchContext):
+    """Try to find a match on given data for this model element
+    and all its children. When a match is found, the matchContext
+    is updated accordingly.
+    @param path the model path to the parent model element invoking
+    this method.
+    @param matchContext an instance of MatchContext class holding
+    the data context to match against.
+    @return the matchElement or None if model did not match."""
     currentPath="%s/%s" % (path, self.id)
-    currentPos=0
-
     startData=matchContext.matchData
     matches=[]
     for childElement in self.children:
